1000Bulbs.com
Description: America's Largest Online Light Bulb Retailer! Thousands of Halogens, CFLs, Automotive Bulbs, Christmas Lights, LEDs, Rope Lights, and Electrical Supplies.
Keywords: Light bulbs, halogen lightbulbs, rope lights, christmas lights, ballasts, fluorescent bulbs

For expert help, call: 1-800-624-4488

Don't have an account? Signup

#### Login

Email Password Remember Me

Forgot Password?

Product Search

For expert help, call: 1-800-624-4488

1000Bulbs.com
2140 Merritt Dr Garland, TX 75041 |  | Phone: 800-624-4488 Fax: 972-543-0538
Hours of operation: 7 a.m. to 7 p.m. CST
Department Contacts
Accounting | Benona King | benona@1000bulbs.com
IT | Mike Timmons | mtimmons@1000bulbs.com
Marketing | Jeremy Foster | jfoster@1000bulbs.com
Purchasing | Mark Samples | msamples@1000bulbs.com

Do you have a return? Please use our RMA Request Form.

For all other questions regarding your order or your account, please fill out the form below.

Fields marked with * are required

First Name *
Last Name*
Company
E-mail *
Address
City
State
Zip
Country
Phone
Fax
I agree to the terms of service. *
Comments